Module: Google::Cloud::Datastore::Admin

Defined in:
lib/google/cloud/datastore/admin.rb,
lib/google/cloud/datastore/admin/version.rb

Constant Summary collapse

VERSION =
"0.7.0"

Class Method Summary collapse

Class Method Details

.configure {|::Google::Cloud.configure.datastore_admin| ... } ⇒ ::Google::Cloud::Config

Configure the google-cloud-datastore-admin library.

The following configuration parameters are supported:

  • credentials (type: String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.
  • lib_name (type: String) - The library name as recorded in instrumentation and logging.
  • lib_version (type: String) - The library version as recorded in instrumentation and logging.
  • interceptors (type: Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.
  • timeout (type: Numeric) - Default timeout in seconds.
  • metadata (type: Hash{Symbol=>String}) - Additional headers to be sent with the call.
  • retry_policy (type: Hash) - The retry policy. The value is a hash with the following keys:
    • :initial_delay (type: Numeric) - The initial delay in seconds.
    • :max_delay (type: Numeric) - The max delay in seconds.
    • :multiplier (type: Numeric) - The incremental backoff multiplier.
    • :jitter (type: Numeric) - The jitter in seconds. Default: 1.0.
    • :retry_codes (type: Array<String>) - The error codes that should trigger a retry.

Yields:

Returns:

  • (::Google::Cloud::Config)

    The default configuration used by this library



194
195
196
197
198
# File 'lib/google/cloud/datastore/admin.rb', line 194

def self.configure
  yield ::Google::Cloud.configure.datastore_admin if block_given?

  ::Google::Cloud.configure.datastore_admin
end

.datastore_admin(version: :v1, transport: :grpc, &block) ⇒ ::Object

Create a new client object for DatastoreAdmin.

By default, this returns an instance of Google::Cloud::Datastore::Admin::V1::DatastoreAdmin::Client for a gRPC client for version V1 of the API. However, you can specify a different API version by passing it in the version parameter. If the DatastoreAdmin service is supported by that API version, and the corresponding gem is available, the appropriate versioned client will be returned. You can also specify a different transport by passing :rest or :grpc in the transport parameter.

Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the DatastoreAdmin service. You can determine whether the method will succeed by calling datastore_admin_available?.

About DatastoreAdmin

Google Cloud Datastore Admin API

The Datastore Admin API provides several admin services for Cloud Datastore.

Concepts: Project, namespace, kind, and entity as defined in the Google Cloud Datastore API.

Operation: An Operation represents work being performed in the background.

EntityFilter: Allows specifying a subset of entities in a project. This is specified as a combination of kinds and namespaces (either or both of which may be all).

Export/Import Service:

  • The Export/Import service provides the ability to copy all or a subset of entities to/from Google Cloud Storage.
  • Exported data may be imported into Cloud Datastore for any Google Cloud Platform project. It is not restricted to the export source project. It is possible to export from one project and then import into another.
  • Exported data can also be loaded into Google BigQuery for analysis.
  • Exports and imports are performed asynchronously. An Operation resource is created for each export/import. The state (including any errors encountered) of the export/import may be queried via the Operation resource.

Index Service:

  • The index service manages Cloud Datastore composite indexes.
  • Index creation and deletion are performed asynchronously. An Operation resource is created for each such asynchronous operation. The state of the operation (including any errors encountered) may be queried via the Operation resource.

Operation Service:

  • The Operations collection provides a record of actions performed for the specified project (including any operations in progress). Operations are not created directly but through calls on other collections or resources.
  • An operation that is not yet done may be cancelled. The request to cancel is asynchronous and the operation may continue to run for some time after the request to cancel is made.
  • An operation that is done may be deleted so that it is no longer listed as part of the Operation collection.
  • ListOperations returns all pending operations, but not completed operations.
  • Operations are created by service DatastoreAdmin, but are accessed via service google.longrunning.Operations.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (::Object)

    A client object for the specified version.



122
123
124
125
126
127
128
129
130
131
132
# File 'lib/google/cloud/datastore/admin.rb', line 122

def self.datastore_admin version: :v1, transport: :grpc, &block
  require "google/cloud/datastore/admin/#{version.to_s.downcase}"

  package_name = Google::Cloud::Datastore::Admin
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  service_module = Google::Cloud::Datastore::Admin.const_get(package_name).const_get(:DatastoreAdmin)
  service_module = service_module.const_get(:Rest) if transport == :rest
  service_module.const_get(:Client).new(&block)
end

.datastore_admin_available?(version: :v1, transport: :grpc) ⇒ boolean

Determines whether the DatastoreAdmin service is supported by the current client. If true, you can retrieve a client object by calling datastore_admin. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the DatastoreAdmin service, or if the versioned client gem needs an update to support the DatastoreAdmin service.

Parameters:

  • version (::String, ::Symbol) (defaults to: :v1)

    The API version to connect to. Optional. Defaults to :v1.

  • transport (:grpc, :rest) (defaults to: :grpc)

    The transport to use. Defaults to :grpc.

Returns:

  • (boolean)

    Whether the service is available.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/google/cloud/datastore/admin.rb', line 146

def self.datastore_admin_available? version: :v1, transport: :grpc
  require "google/cloud/datastore/admin/#{version.to_s.downcase}"
  package_name = Google::Cloud::Datastore::Admin
                 .constants
                 .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") }
                 .first
  return false unless package_name
  service_module = Google::Cloud::Datastore::Admin.const_get package_name
  return false unless service_module.const_defined? :DatastoreAdmin
  service_module = service_module.const_get :DatastoreAdmin
  if transport == :rest
    return false unless service_module.const_defined? :Rest
    service_module = service_module.const_get :Rest
  end
  service_module.const_defined? :Client
rescue ::LoadError
  false
end